@@ -18,28 +18,28 @@
 #'
 #' @examples
 #' data(nydf)
-#' coords = with(nydf, cbind(longitude, latitude))
-#' d = sp::spDists(as.matrix(coords), longlat = TRUE)
-#' nn = casewin(d, cases = nydf$pop, cstar = 15000)
-#' cases = floor(nydf$cases)
-#' ty = sum(cases)
-#' ex = ty/sum(nydf$pop) * nydf$pop
+#' coords <- with(nydf, cbind(longitude, latitude))
+#' d <- sp::spDists(as.matrix(coords), longlat = TRUE)
+#' nn <- casewin(d, cases = nydf$pop, cstar = 15000)
+#' cases <- floor(nydf$cases)
+#' ty <- sum(cases)
+#' ex <- ty / sum(nydf$pop) * nydf$pop
 #' # find smallest windows with at least n* pop
-#' nstar = 1000
-#' nn = casewin(d, cases = nydf$pop, cstar = nstar)
+#' nstar <- 1000
+#' nn <- casewin(d, cases = nydf$pop, cstar = nstar)
 #' # determine ts
-#' wts = cepp.weights(nn, nydf$pop, nstar)
-#' tsim = cepp.sim(1, nn = nn, ty = ty, ex = ex, wts = wts)
-cepp.sim = function(nsim = 1, nn, ty, ex, wts, simdist = "multinomial") {
+#' wts <- cepp.weights(nn, nydf$pop, nstar)
+#' tsim <- cepp.sim(1, nn = nn, ty = ty, ex = ex, wts = wts)
+cepp.sim <- function(nsim = 1, nn, ty, ex, wts, simdist = "multinomial") {
   # compute max test stat for nsim simulated data sets
-  tsim = pbapply::pblapply(seq_len(nsim), function(idx) {
+  tsim <- pbapply::pblapply(seq_len(nsim), function(idx) {
     # simulate new data
     if (simdist == "multinomial") {
-      ysim = stats::rmultinom(1, size = ty, prob = ex)
+      ysim <- stats::rmultinom(1, size = ty, prob = ex)
     } else {
-      ysim = stats::rpois(length(ex), lambda = ex)
+      ysim <- stats::rpois(length(ex), lambda = ex)
     }
-    cstar = sapply(seq_along(nn), function(i) {
+    cstar <- sapply(seq_along(nn), function(i) {
       sum(ysim[nn[[i]]] * wts[[i]])
     })
     max(cstar)
