@@ -40,85 +40,100 @@
 #' @examples
 #' data(nydf)
 #' data(nyw)
-#' coords = with(nydf, cbind(longitude, latitude))
-#' out = dc.test(coords = coords, cases = floor(nydf$cases),
-#'               pop = nydf$population, w = nyw,
-#'               alpha = 0.12, longlat = TRUE,
-#'               nsim = 5, ubpop = 0.1, ubd = 0.2)
+#' coords <- with(nydf, cbind(longitude, latitude))
+#' out <- dc.test(
+#'   coords = coords, cases = floor(nydf$cases),
+#'   pop = nydf$population, w = nyw,
+#'   alpha = 0.12, longlat = TRUE,
+#'   nsim = 5, ubpop = 0.1, ubd = 0.2
+#' )
 #' data(nypoly)
 #' library(sp)
 #' plot(nypoly, col = color.clusters(out))
-dc.test = function(coords, cases, pop, w,
-                   ex = sum(cases) / sum(pop) * pop,
-                   nsim = 499, alpha = 0.1,
-                   ubpop = 0.5, ubd = 1,
-                   longlat = FALSE, cl = NULL) {
+dc.test <- function(coords, cases, pop, w,
+                    ex = sum(cases) / sum(pop) * pop,
+                    nsim = 499, alpha = 0.1,
+                    ubpop = 0.5, ubd = 1,
+                    longlat = FALSE, cl = NULL) {
   # sanity checking
-  arg_check_scan_test(coords = coords, cases = cases,
-                      pop = pop, ex = ex, nsim = nsim,
-                      alpha = alpha,
-                      ubpop = ubpop, longlat = longlat,
-                      k = 1, w = w)
+  arg_check_scan_test(
+    coords = coords, cases = cases,
+    pop = pop, ex = ex, nsim = nsim,
+    alpha = alpha,
+    ubpop = ubpop, longlat = longlat,
+    k = 1, w = w
+  )
 
-  coords = as.matrix(coords) # ensure proper format
-  N = nrow(coords) # number of regions
-  ty = sum(cases) # sum of all cases
+  coords <- as.matrix(coords) # ensure proper format
+  N <- nrow(coords) # number of regions
+  ty <- sum(cases) # sum of all cases
 
   # intercentroid distances
-  d = sp::spDists(as.matrix(coords), longlat = TRUE)
+  d <- sp::spDists(as.matrix(coords), longlat = TRUE)
   # upperbound for zone populations
-  max_pop = ubpop * sum(pop)
+  max_pop <- ubpop * sum(pop)
   # find all neighbors from each starting zone within distance upperbound
-  nn = nndist(d, ubd)
+  nn <- nndist(d, ubd)
 
-  all_zones = mst.all(nn, cases = cases, pop = pop, w = w,
-                      ex = ex, ty = ty, max_pop = max_pop,
-                      type = "all", nlinks = "two", early = TRUE,
-                      cl = cl, progress = FALSE)
+  all_zones <- mst.all(nn,
+    cases = cases, pop = pop, w = w,
+    ex = ex, ty = ty, max_pop = max_pop,
+    type = "all", nlinks = "two", early = TRUE,
+    cl = cl, progress = FALSE
+  )
   # extract relevant information
-  nn2 = lapply(all_zones, getElement, name = "locids")
-  tobs = unlist(lapply(all_zones, getElement, name = "loglikrat"),
-                use.names = FALSE)
+  nn2 <- lapply(all_zones, getElement, name = "locids")
+  tobs <- unlist(lapply(all_zones, getElement, name = "loglikrat"),
+    use.names = FALSE
+  )
   # determine distinct zones
-  wdup = nndup(nn2, N)
+  wdup <- nndup(nn2, N)
 
   # remove zones with a test statistic of 0 or don't have
   # min number of cases or are duplicted
-  w0 = which(tobs == 0 | wdup)
+  w0 <- which(tobs == 0 | wdup)
 
   # determine zones
-  zones = nn2zones(nn2)
+  zones <- nn2zones(nn2)
 
   # remove zones with a test statistic of 0
-  zones = zones[-w0]
-  tobs = tobs[-w0]
+  zones <- zones[-w0]
+  tobs <- tobs[-w0]
 
   # compute test statistics for simulated data
   if (nsim > 0) {
     message("computing statistics for simulated data:")
-    tsim = dc.sim(nsim = nsim, nn = nn, ty = ty,
-                  ex = ex, w = w, pop = pop,
-                  max_pop = max_pop, cl = cl)
-    pvalue = mc.pvalue(tobs, tsim)
+    tsim <- dc.sim(
+      nsim = nsim, nn = nn, ty = ty,
+      ex = ex, w = w, pop = pop,
+      max_pop = max_pop, cl = cl
+    )
+    pvalue <- mc.pvalue(tobs, tsim)
   } else {
-    pvalue = rep(1, length(tobs))
+    pvalue <- rep(1, length(tobs))
   }
 
   # significant, ordered, non-overlapping clusters and
   # information
-  pruned = sig_noc(tobs = tobs, zones = zones,
-                   pvalue = pvalue, alpha = alpha,
-                   order_by = "tobs")
+  pruned <- sig_noc(
+    tobs = tobs, zones = zones,
+    pvalue = pvalue, alpha = alpha,
+    order_by = "tobs"
+  )
 
-  smerc_cluster(tobs = pruned$tobs, zones = pruned$zones,
-                pvalue = pruned$pvalue, coords = coords,
-                cases = cases, pop = pop, ex = ex,
-                longlat = longlat, method = "double connection",
-                rel_param = list(type = "poisson",
-                                 simdist = "multinomial",
-                                 nsim = nsim,
-                                 ubpop = ubpop,
-                                 ubd = ubd),
-                alpha = alpha,
-                w = w, d = NULL)
+  smerc_cluster(
+    tobs = pruned$tobs, zones = pruned$zones,
+    pvalue = pruned$pvalue, coords = coords,
+    cases = cases, pop = pop, ex = ex,
+    longlat = longlat, method = "double connection",
+    rel_param = list(
+      type = "poisson",
+      simdist = "multinomial",
+      nsim = nsim,
+      ubpop = ubpop,
+      ubd = ubd
+    ),
+    alpha = alpha,
+    w = w, d = NULL
+  )
 }
