@@ -24,34 +24,40 @@
 #' @examples
 #' data(nydf)
 #' data(nyw)
-#' coords = as.matrix(nydf[,c("longitude", "latitude")])
+#' coords <- as.matrix(nydf[, c("longitude", "latitude")])
 #' # find zone with max statistic starting from each individual region
-#' all_zones = dmst.zones(coords, cases = floor(nydf$cases),
-#'                         nydf$pop, w = nyw, ubpop = 0.25,
-#'                         ubd = .25, longlat = TRUE)
-dmst.zones = function(coords, cases, pop, w,
+#' all_zones <- dmst.zones(coords,
+#'   cases = floor(nydf$cases),
+#'   nydf$pop, w = nyw, ubpop = 0.25,
+#'   ubd = .25, longlat = TRUE
+#' )
+dmst.zones <- function(coords, cases, pop, w,
                        ex = sum(cases) / sum(pop) * pop,
                        ubpop = 0.5, ubd = 1, longlat = FALSE,
                        cl = NULL, progress = TRUE) {
   # sanity checking
-  arg_check_dmst_zones(coords = coords, cases = cases,
-                       pop = pop, w = w, ex = ex,
-                       ubpop = ubpop, ubd = ubd,
-                       longlat = longlat, type = "all",
-                       progress = progress)
+  arg_check_dmst_zones(
+    coords = coords, cases = cases,
+    pop = pop, w = w, ex = ex,
+    ubpop = ubpop, ubd = ubd,
+    longlat = longlat, type = "all",
+    progress = progress
+  )
   # setup various arguments and such
-  ty = sum(cases)   # total number of cases
+  ty <- sum(cases) # total number of cases
   # intercentroid distances
-  d = sp::spDists(as.matrix(coords), longlat = longlat)
+  d <- sp::spDists(as.matrix(coords), longlat = longlat)
   # upperbound for population in zone
-  max_pop = ubpop * sum(pop)
+  max_pop <- ubpop * sum(pop)
   # find all neighbors from each starting zone within distance upperbound
-  nn = nndist(d, ubd)
+  nn <- nndist(d, ubd)
   # get zones and relevant information
-  out = mst.all(neighbors = nn, cases = cases, pop = pop,
-                w = w, ex = ex, ty = ty, max_pop = max_pop,
-                type = "all", nlinks = "one", early = FALSE,
-                cl = cl, progress = progress)
+  out <- mst.all(
+    neighbors = nn, cases = cases, pop = pop,
+    w = w, ex = ex, ty = ty, max_pop = max_pop,
+    type = "all", nlinks = "one", early = FALSE,
+    cl = cl, progress = progress
+  )
   prep.mst(out)
 }
 
@@ -61,20 +67,25 @@ dmst.zones = function(coords, cases, pop, w,
 #' @return NULL
 #' @export
 #' @keywords internal
-prep.mst = function(mstout) {
-  nn = lapply(mstout, getElement, name = "locids")
-  loglikrat = unlist(lapply(mstout, getElement,
-                            name = "loglikrat"))
-  cases = unlist(lapply(mstout, getElement, name = "cases"))
-  expected = unlist(lapply(mstout, getElement,
-                           name = "expected"))
-  population = unlist(lapply(mstout, getElement,
-                             name = "population"))
-  return(list(zones = nn2zones(nn),
-              loglikrat = loglikrat,
-              cases = cases,
-              expected = expected,
-              population = population))
+prep.mst <- function(mstout) {
+  nn <- lapply(mstout, getElement, name = "locids")
+  loglikrat <- unlist(lapply(mstout, getElement,
+    name = "loglikrat"
+  ))
+  cases <- unlist(lapply(mstout, getElement, name = "cases"))
+  expected <- unlist(lapply(mstout, getElement,
+    name = "expected"
+  ))
+  population <- unlist(lapply(mstout, getElement,
+    name = "population"
+  ))
+  return(list(
+    zones = nn2zones(nn),
+    loglikrat = loglikrat,
+    cases = cases,
+    expected = expected,
+    population = population
+  ))
 }
 
 #' Argument checking for dmst.zones, dc.zones, and
@@ -84,11 +95,11 @@ prep.mst = function(mstout) {
 #' mlink.zones functions.
 #' @return NULL
 #' @noRd
-arg_check_dmst_zones = function(coords, cases, pop, w, ex,
-                                ubpop, ubd, longlat, type,
-                                progress = FALSE) {
+arg_check_dmst_zones <- function(coords, cases, pop, w, ex,
+                                 ubpop, ubd, longlat, type,
+                                 progress = FALSE) {
   arg_check_coords(coords)
-  N = nrow(coords)
+  N <- nrow(coords)
   arg_check_cases(cases, N)
   arg_check_pop(pop, N)
   arg_check_w(w, N)
@@ -103,4 +114,3 @@ arg_check_dmst_zones = function(coords, cases, pop, w, ex,
     stop("progress must be a logical value")
   }
 }
-
