@@ -45,76 +45,87 @@
 #'   <doi:10.1111/j.1467-9868.2011.01014.x>
 #' @examples
 #' data(nydf)
-#' coords = with(nydf, cbind(longitude, latitude))
-#' out = fast.test(coords = coords, cases = floor(nydf$cases),
-#'                pop = nydf$pop,
-#'                alpha = 0.05, longlat = TRUE,
-#'                nsim = 49, ubpop = 0.5)
-fast.test = function(coords, cases, pop,
-                    ex = sum(cases) / sum(pop) * pop,
-                    nsim = 499, alpha = 0.1,
-                    ubpop = 0.5, longlat = FALSE,
-                    cl = NULL, type = "poisson") {
+#' coords <- with(nydf, cbind(longitude, latitude))
+#' out <- fast.test(
+#'   coords = coords, cases = floor(nydf$cases),
+#'   pop = nydf$pop,
+#'   alpha = 0.05, longlat = TRUE,
+#'   nsim = 49, ubpop = 0.5
+#' )
+fast.test <- function(coords, cases, pop,
+                      ex = sum(cases) / sum(pop) * pop,
+                      nsim = 499, alpha = 0.1,
+                      ubpop = 0.5, longlat = FALSE,
+                      cl = NULL, type = "poisson") {
   # sanity checking
   arg_check_scan_test(coords, cases, pop, ex, nsim, alpha,
-                      nsim + 1, ubpop, longlat, TRUE,
-                      k = 1, w = diag(nrow(coords)),
-                      type = type)
+    nsim + 1, ubpop, longlat, TRUE,
+    k = 1, w = diag(nrow(coords)),
+    type = type
+  )
 
-  coords = as.matrix(coords)
-  zones = fast.zones(cases, pop, ubpop)
+  coords <- as.matrix(coords)
+  zones <- fast.zones(cases, pop, ubpop)
 
   # compute needed information
-  ty = sum(cases)
-  yin = cumsum(cases[zones])
+  ty <- sum(cases)
+  yin <- cumsum(cases[zones])
 
   # compute test statistics for observed data
   if (type == "poisson") {
-    ein = cumsum(ex[zones])
-    tobs = stat.poisson(yin, ty - yin, ein, ty - ein)
+    ein <- cumsum(ex[zones])
+    tobs <- stat.poisson(yin, ty - yin, ein, ty - ein)
   } else if (type == "binomial") {
-    tpop = sum(pop)
-    popin = cumsum(pop[zones])
-    tobs = stat.binom(yin, ty - yin, ty, popin, tpop - popin, tpop)
+    tpop <- sum(pop)
+    popin <- cumsum(pop[zones])
+    tobs <- stat.binom(yin, ty - yin, ty, popin, tpop - popin, tpop)
   }
 
   # compute test statistics for simulated data
   if (nsim > 0) {
     message("computing statistics for simulated data:")
-    tsim = fast.sim(nsim = nsim, ty = ty, ex = ex,
-                   pop = pop, ubpop = ubpop, cl = cl)
-    pvalue = mc.pvalue(tobs, tsim)
+    tsim <- fast.sim(
+      nsim = nsim, ty = ty, ex = ex,
+      pop = pop, ubpop = ubpop, cl = cl
+    )
+    pvalue <- mc.pvalue(tobs, tsim)
   } else {
-    pvalue = rep(1, length(tobs))
+    pvalue <- rep(1, length(tobs))
   }
 
   # determine which potential clusters are significant
-  sigc = which(pvalue <= alpha, useNames = FALSE)
+  sigc <- which(pvalue <= alpha, useNames = FALSE)
 
   # if there are no significant clusters, return most likely cluster
   if (length(sigc) == 0) {
-    sigc = which.max(tobs)
+    sigc <- which.max(tobs)
     warning("No significant clusters.  Returning most likely cluster.")
   }
 
   # reformat zones
-  zones = lapply(seq_along(zones), function(i) zones[seq_len(i)])
+  zones <- lapply(seq_along(zones), function(i) zones[seq_len(i)])
 
   # significant, ordered, non-overlapping clusters and
   # information
-  pruned = sig_noc(tobs = tobs,
-                   zones = zones,
-                   pvalue = pvalue, alpha = alpha,
-                   order_by = "tobs")
+  pruned <- sig_noc(
+    tobs = tobs,
+    zones = zones,
+    pvalue = pvalue, alpha = alpha,
+    order_by = "tobs"
+  )
 
-  smerc_cluster(tobs = pruned$tobs, zones = pruned$zones,
-                pvalue = pruned$pvalue, coords = coords,
-                cases = cases, pop = pop, ex = ex,
-                longlat = longlat, method = "fast",
-                rel_param = list(type = type,
-                                 simdist = "multinomial",
-                                 nsim = nsim,
-                                 ubpop = ubpop),
-                alpha = alpha,
-                w = NULL, d = NULL)
+  smerc_cluster(
+    tobs = pruned$tobs, zones = pruned$zones,
+    pvalue = pruned$pvalue, coords = coords,
+    cases = cases, pop = pop, ex = ex,
+    longlat = longlat, method = "fast",
+    rel_param = list(
+      type = type,
+      simdist = "multinomial",
+      nsim = nsim,
+      ubpop = ubpop
+    ),
+    alpha = alpha,
+    w = NULL, d = NULL
+  )
 }
